Information | Chart.js
Description: Open source HTML5 Charts for your website

# # Information

## # Out of the box working samples

These samples are made for demonstration purposes only. They won't work out of the box if you copy paste them into your own website. This is because of how the docs are getting built. Some boilerplate code gets hidden. For a sample that can be copied and pasted and used directly you can check the usage page.

## # Autogenerated data

The data used in the samples is autogenerated using custom functions. These functions do not ship with the library, for more information about this you can check the utils page.

## # Actions block

The samples have an `actions` code block. These actions are not part of chart.js. They are internally transformed to separate buttons together with onClick listeners by a plugin we use in the documentation. To implement such actions yourself you can make some buttons and add onClick event listeners to them. Then in these event listeners you can call your variable in which you made the chart and do the logic that the button is supposed to do.